# Generated manually
S3method(print, mqq_regression)
S3method(summary, mqq_regression)
S3method(plot, mqq_regression)
export(mqq_regression)
export(mqq_export)
export(mqq_to_matrix)
export(mqq_statistics)
export(plot_mqq_3d)
export(plot_mqq_heatmap)
export(plot_mqq_contour)
export(plot_mqq_interaction)
export(qq_weights)
export(gaussian_kernel)
export(weighted_qr)
export(parula_colors)
export(matlab_jet_colors)
export(turbo_colors)
export(bluered_colors)
export(sinha_colors)
export(mqqr_colorscales)
export(mqqr_palette)
export(resolve_colorscale)
importFrom(grDevices, colorRampPalette)
importFrom(plotly, plot_ly)
importFrom(plotly, layout)
importFrom(plotly, "%>%")
importFrom(quantreg, rq.wfit)
importFrom(stats, complete.cases)
importFrom(stats, cor)
importFrom(stats, dnorm)
importFrom(stats, median)
importFrom(stats, pnorm)
importFrom(stats, predict)
importFrom(stats, pt)
importFrom(stats, quantile)
importFrom(stats, sd)
importFrom(stats, var)
importFrom(utils, write.csv)
