.onAttach <- function(libname, pkgname) {
  packageStartupMessage(
    "mqqr 1.0.0  Multivariate Quantile-on-Quantile Regression\n",
    "  Default colour scale: MATLAB Parula. See mqqr_colorscales()."
  )
}
